function [ P, K, M ,center ] = readProjMat( proj_path, camNo )
%% This reads the projection matrices
% READPROJMAT Reads the camera projection matrix P,K,M
% The file must contain projection matrices in milimiters and it is
% corrected to meters
%    INPUT:
%       proj_path: Path where the projection matrices are located
%       camNo: camera number
%    OUTPUT:
%         P: Total projection matrix
%         K: Intrinsic camera paramters
%         M: Extrinisc projection matrix, maps points from world to camera frame
%         center: camera center
%
% This function is part of the MPI08 data set, to be obtained at 
% http://www.tnt.uni-hannover.de/project/MPI08_Database/
%
% Written by: Gerard Pons
% Revision:   1.0
% Date:       28.09.2010
%
% Copyright 2010, MPI Informatik, Germany, and Hannover University, Germany.
% All Rights Reserved Permission to use, copy, modify, and distribute this
% software and its documentation for any non-commercial purpose is hereby
% granted without fee, provided that the above copyright notice appear in
% all copies and that both that copyright notice and this permission
% notice appear in supporting documentation, and that the name of the
% author not be used in advertising or publicity pertaining to distribution
% of the software without specific, written prior permission.
% THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
% INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR ANY
% PARTICULAR PURPOSE. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
% SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER
% RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF
% CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
% CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.



fname= fullfile(proj_path, sprintf('proj%02g.dat',camNo));
fid=fopen(fname,'r');
if (fid==-1)
    error(['Could not open the file ' fname])
    return;
end
l='null';
while (strcmp(l,'P:')~=1)
    l = fgetl(fid);
end
% Total projection matrix
P=fscanf(fid, '%f %f %f', [4 3])';
% Correct from milimiters to meters
P(:, 4) = P(:, 4)/1000;
while (strcmp(l,'K:')~=1)
    l = fgetl(fid);
end
% Intrinsics
K=fscanf(fid, '%f %f %f', [3 3])';
while (strcmp(l,'M:')~=1)
    l = fgetl(fid);
end
% Extrinsics
M=fscanf(fid, '%f %f %f', [4 4])';
center=-M(1:3,1:3)*M(1:3,4);
fclose(fid);
end